@@ -78,12 +78,12 @@ def load_columns(df, output_df, groups, cols, kvr_duo_delta_columns, dim, pca):
     информация обо всех проходах будет использована в обучении модели
     и, соответственно, для предсказания.
     '''
-    duo_uss = group_starts_with['Group_ДУО_УСС_01']
-    kvr_uss = group_starts_with['Group_КВР_УСС_01']
-    for col in duo_uss+kvr_uss:
-        ind = df[df[col]<0].index
-        temp = df[col].copy()
-        df[col].loc[ind] = 0
+    # duo_uss = group_starts_with['Group_ДУО_УСС_01']
+    # kvr_uss = group_starts_with['Group_КВР_УСС_01']
+    # for col in duo_uss+kvr_uss:
+    #     ind = df[df[col]<0].index
+    #     temp = df[col].copy()
+    #     df[col].loc[ind] = 0
 
     for columns in groups:
         if isinstance(columns, list): # convolve
@@ -107,7 +107,7 @@ def load_targets(df, Y, targets):
     return
 
 
-# TO DO: to change when Filters_date is added
+# TO DO: to delete
 def time2num(df, columns, cols):
     for column in columns:
         if column in cols:
@@ -278,11 +278,11 @@ class Data_Preprocessor:
             df = pd.DataFrame(columns=df.keys(), data=[df, df], index=[0, 1])
 
         if self.is_features_invoked:
-            time2num(df, time_columns, self.features)
+            # time2num(df, time_columns, self.features)
             encode(df, data, label_encoders, self.features)
             process_error_codes(df, data, error_codes, self.features)
         else:
-            time2num(df, time_columns, df.columns.values)
+            # time2num(df, time_columns, df.columns.values)
             encode(df, data, label_encoders, df.columns.values)
             process_error_codes(df, data, error_codes, df.columns.values)
 
