@@ -86,9 +86,11 @@ class DB_Connector:
         query = f'select * from MetricToModels WHERE model_id={model_id} and metric_id={metric_id}'
         df = read_sql_query(query, self.conn)
 
-        metric = df[df.time==df.time.max()].value.iloc[0]
-
-        return int(metric)
+        if not df.empty:
+            metric = df[df.time==df.time.max()].value.iloc[0]
+            return int(metric)
+        else:
+            return -1
 
     def insert_metrics(self, model_id:int,
                        metrics: dict[str, dict[str, str]],
